@@ -6,19 +6,31 @@ tabs = ['']
 def DepthTraversal(nowDir, p):
     # 根据目录建立列表
     baseName = os.path.basename(nowDir)
-    c = [baseName]
+    p.append(baseName)
+    c = []    
+    #c = [baseName]
     p.append(c)
 
     ls = os.listdir(nowDir)
     for each in ls:
-        nextPath = nowDir + os.sep + each
+        nextPath = os.path.join(nowDir, each)
         nextPath_basename = os.path.basename(nextPath)
         if os.path.isdir(nextPath):
             DepthTraversal(nextPath, c)
         else:
             nextPath_basename = os.path.basename(nextPath)
-            p.append(nextPath_basename)
-def tree(lst):
+            c.append(nextPath_basename)
+def tree(lst,level = 0):
+    for name in lst:
+        if isinstance(name,list):
+            tree(name,level + 1)
+        else:
+            if level>0:
+                print(blank[0]* 3 * (level), name)
+            else:
+                print( name)
+
+def tree1(lst):
     # 树状图输出列表
     l = len(lst)
     if l == 0:
@@ -49,6 +61,22 @@ def tree(lst):
                 #f.write(j + "\n")
     tabs[0] = tabs[0][:-3]
 
+def travelTree(currentPath, count=0):
+    if not os.path.exists(currentPath):
+        print("no current Path")
+        return 
+    if os.path.isfile(currentPath):
+        fileName = os.path.basename(currentPath)
+        print( "  "*count + "|_ "+fileName )
+    elif os.path.isdir(currentPath):
+    	#print currentPath 
+        print("  "*count + "|_ "+currentPath) 
+        pathList = os.listdir(currentPath)
+        for eachPath in pathList:
+            travelTree(currentPath + '/' + eachPath, count + 1)
+    else:
+        print("\n")
+    	#return
 def main(args = None):
     if len(sys.argv) <=1:
         paths ='.'
@@ -62,7 +90,10 @@ def main(args = None):
     #f = open("out", 'w')
     TreeList = []
     DepthTraversal(path, TreeList)
+    print(TreeList)
     tree(TreeList)
+    #travelTree(path)
+
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
